@@ -1,8 +1,9 @@
-import _curry2 from './internal/_curry2';
+import _curry2 from './internal/_curry2.js';
 
 
 /**
- * Returns `true` if both arguments are `true`; `false` otherwise.
+ * Returns the first argument if it is falsy, otherwise the second argument.
+ * Acts as the boolean `and` statement if both inputs are `Boolean`s.
  *
  * @func
  * @memberOf R
@@ -11,8 +12,8 @@ import _curry2 from './internal/_curry2';
  * @sig a -> b -> a | b
  * @param {Any} a
  * @param {Any} b
- * @return {Any} the first argument if it is falsy, otherwise the second argument.
- * @see R.both, R.xor
+ * @return {Any}
+ * @see R.both, R.or
  * @example
  *
  *      R.and(true, true); //=> true
