@@ -1,5 +1,5 @@
-import _curry1 from './internal/_curry1';
-import curryN from './curryN';
+import _curry1 from './internal/_curry1.js';
+import curryN from './curryN.js';
 
 
 /**
