@@ -1,4 +1,4 @@
-import _isArray from './_isArray';
+import _isArray from './_isArray.js';
 
 
 /**
@@ -7,7 +7,7 @@ import _isArray from './_isArray';
  * implementation.
  *
  * @private
- * @param {Function} fn ramda implemtation
+ * @param {Function} fn ramda implementation
  * @param {String} methodname property to check for a custom implementation
  * @return {Object} Whatever the return value of the method is.
  */
