@@ -1,7 +1,7 @@
-import _curry2 from './internal/_curry2';
-import _isFunction from './internal/_isFunction';
-import curryN from './curryN';
-import toString from './toString';
+import _curry2 from './internal/_curry2.js';
+import _isFunction from './internal/_isFunction.js';
+import curryN from './curryN.js';
+import toString from './toString.js';
 
 
 /**
