@@ -1,4 +1,4 @@
-import _curry1 from './internal/_curry1';
+import _curry1 from './internal/_curry1.js';
 
 
 /**
