@@ -1,5 +1,5 @@
-import _curry1 from './internal/_curry1';
-import _isNumber from './internal/_isNumber';
+import _curry1 from './internal/_curry1.js';
+import _isNumber from './internal/_isNumber.js';
 
 
 /**
