@@ -1,5 +1,5 @@
-import _curry2 from './internal/_curry2';
-import _isInteger from './internal/_isInteger';
+import _curry2 from './internal/_curry2.js';
+import _isInteger from './internal/_isInteger.js';
 
 
 /**
