@@ -1,4 +1,4 @@
-import invoker from './invoker';
+import invoker from './invoker.js';
 
 
 /**
