@@ -1,5 +1,5 @@
-import _curry1 from './internal/_curry1';
-import _toString from './internal/_toString';
+import _curry1 from './internal/_curry1.js';
+import _toString from './internal/_toString.js';
 
 
 /**
